import matplotlib.pyplot as plt
import seaborn as sns
import pandas as pd
import matplotlib.dates as mdates

from sklearn.impute import SimpleImputer


## 1. Exploratory Data Analysis
def exploratory_data_analysis(data):
    """
    Perform exploratory data analysis on a dataset with 15-minute time intervals.

    Args:
        data (pd.DataFrame): Input dataset with a datetime column named 'Time'.

    Returns:
        pd.DataFrame: Processed DataFrame with additional features.
    """
    # Ensure 'Time' column is in datetime format
    data['Time'] = pd.to_datetime(data['Time'])

    # Set 'Time' column as the index
    data.set_index('Time', inplace=True)

    # Extract temporal features
    data['Hour'] = data.index.hour
    data['Minute'] = data.index.minute
    data['Day'] = data.index.day
    data['Weekday'] = data.index.weekday  # 0=Monday, 6=Sunday
    data['Month'] = data.index.month
    data['DayOfYear'] = data.index.dayofyear

    # Check for missing values and impute with column mean
    imputer = SimpleImputer(strategy="mean")
    data.iloc[:, :] = imputer.fit_transform(data)

    # Display summary statistics
    return data

import numpy as np  
import pandas as pd
import seaborn as sns
import matplotlib.pyplot as plt

def plot_daily_mean_power(data):
    # Load the dataset into a DataFrame
    df = pd.DataFrame(data)
    
    # Ensure the 'Time' column is in datetime format
    df['Time'] = pd.to_datetime(df['Time'])
    
    # Set 'Time' as the index
    df.set_index('Time', inplace=True)
    
    # Check for missing values and impute numerical columns with column mean
    numerical_columns = df.select_dtypes(include=np.number).columns
    imputer = SimpleImputer(strategy="mean")
    df[numerical_columns] = imputer.fit_transform(df[numerical_columns])
    
    # Resample the data to get the mean daily value
    daily_mean = df.resample('D').mean()
    
    # Reset the index to make 'Time' a column again
    daily_mean = daily_mean.reset_index()
    
    # Reshape the data to long format
    daily_mean_long = daily_mean.melt(id_vars='Time', var_name='Power_Type', value_name='Mean_Value')
    
    # Set seaborn style
    sns.set(style="ticks")
    
    # Plot the data
    plt.figure(figsize=(14, 7))
    sns.lineplot(data=daily_mean_long, x='Time', y='Mean_Value', hue='Power_Type', linewidth=2.5)
    
    plt.xlabel('Date', fontsize=14)
    plt.ylabel('Mean Daily Value', fontsize=14)
    plt.title('Mean Daily Power Values', fontsize=16)
    plt.legend(title='Power Type', fontsize=12, title_fontsize=12)
    plt.grid(True, which='both', linestyle='--', linewidth=0.5)
    
    # Rotate x-axis labels for better readability
    plt.xticks(rotation=45, fontsize=12)
    plt.yticks(fontsize=12)
    
    # Improve date formatting on x-axis
    plt.gca().xaxis.set_major_locator(plt.MaxNLocator(10))
    plt.gcf().autofmt_xdate()
    
    plt.tight_layout()  # Adjust layout to prevent label overlap
    plt.show()


# Main Program to run the clustering
if __name__ == "__main__":
    # Load the dataset
    data = pd.read_csv("/home/jvaldes/Desktop/krishna-thesis/thesiscodeimplementation/data/Autohaus 2.csv")  # Replace with your dataset file

    #df = exploratory_data_analysis(data)
    plot_daily_mean_power(data)
